within SorpLib.Media.WorkingPairs.PureComponents.H2O;
model AQSOAZ02_DubininLorentzianCumulative_Goldsworthy2014_Bau2017_VLE
  "H2O & AQSOA-Z02 via the Dubinin isotherm model with a Lorentzian Cumulative according to measurment data from Goldsworty (2014) and fit from Bau (2017)"
  extends SorpLib.Media.WorkingPairs.PureComponents.WorkingPairVLE(
    redeclare replaceable package Medium =
      Modelica.Media.Water.StandardWater,
    redeclare final package WorkingPair =
      SorpLib.Media.WorkingPairs.Parametrizations.PureComponents.H2O.AQSOAZ02_DubininLorentzianCumulative_Goldsworthy2014_Bau2017
        (redeclare final package MediumSpecificFunctions =
          SorpLib.Media.WorkingPairs.Parametrizations.PureComponents.MediumSpecificFunctions.VLE
            (
          redeclare final package Medium = Medium)),
    v_adsorpt_constant=1/947,
    cp_adsorpt_constant=4.3e3,
    h_ads_constant=2750e3);

  //
  // Annotations
  //
  annotation (Documentation(info="<html>
<p>
This model calculates the adsorption equilibrium and thermodynamic properties of 
the working pair H<sub>2</sub>0 & AQSOA-Z02 (FAM-Z02) using the Dubinin isotherm 
model with a Lorentzian Cumulative characteristic curve generated by Bau (2017) 
using measurement data from Goldsworthy (2014).
</p>

<h4>References</h4>
<ul>
  <li>
  Goldsworthy (2014). Measurements of water vapour sorption isotherms for RD silica gel, AQSOA-Z01, AQSOA-Z02, AQSOA-Z05 and CECA zeolite 3A, Microporous and Mesoporous Materials, 196:59-67. DOI: http://dx.doi.org/10.1016/j.micromeso.2014.04.046.
  </li>
  <li>
  Bau (2018). From Dynamic Simulation to Optimal Design and Control of Adsorption Energy Systems, PhD thesis. DOI: https://doi.org/10.18154/RWTH-2018-222524.
  </li>
</ul>
</html>", revisions="<html>
<ul>
  <li>
  November 22, 2023, by Mirko Engelpracht:<br/>
  Revision after restructering of the library.
  </li>
  <li>
  December 14, 2020, by Mirko Engelpracht:<br/>
  Revision after restructering of the library.
  </li>
  <li>
  November 17, 2017, by Uwe Bau:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>"));
end AQSOAZ02_DubininLorentzianCumulative_Goldsworthy2014_Bau2017_VLE;
